@@ -1,16 +1,13 @@
-/* $Id: gucharmap-intl.c,v 1.2 2005/09/08 13:35:59 behdad Exp $ */
+/* $Id: gucharmap-intl.c,v 1.4 2006/07/24 23:06:31 behdad Exp $ */
 
 #include "config.h"
+
 #include "gucharmap-intl.h"
 
-#ifdef ENABLE_NLS
-
-#include <libintl.h>
-#include <gtk/gtk.h>
-
-gchar *
-gucharmap_gettext (const gchar *str)
+void
+_gucharmap_intl_ensure_initialized (void)
 {
+#ifdef ENABLE_NLS
   static gboolean gucharmap_gettext_initialized = FALSE;
 
   if (!gucharmap_gettext_initialized)
@@ -19,10 +16,8 @@ gucharmap_gettext (const gchar *str)
 #ifdef HAVE_BIND_TEXTDOMAIN_CODESET
       bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 #endif
+
       gucharmap_gettext_initialized = TRUE;
     }
-
-  return dgettext (GETTEXT_PACKAGE, str);
-}
-
 #endif /* #ifdef ENABLE_NLS */
+}
