@@ -1,4 +1,4 @@
-/* $Id: gucharmap-script-chapters.c,v 1.7 2006/02/12 00:07:14 behdad Exp $ */
+/* $Id: gucharmap-script-chapters.c,v 1.9 2006/07/24 23:06:31 behdad Exp $ */
 /*
  * Copyright (c) 2004 Noah Levitt
  *
@@ -120,14 +120,15 @@ get_codepoint_list (GucharmapChapters *chapters)
       gtk_tree_model_get (model, &iter, SCRIPT_CHAPTERS_SCRIPT_UNTRANSLATED, &script_untranslated, -1);
 
       list = gucharmap_script_codepoint_list_new ();
-      if (gucharmap_script_codepoint_list_set_script (GUCHARMAP_SCRIPT_CODEPOINT_LIST (list), script_untranslated))
-        return list;
-      else
+      if (!gucharmap_script_codepoint_list_set_script (GUCHARMAP_SCRIPT_CODEPOINT_LIST (list), script_untranslated))
         {
           g_error ("gucharmap_script_codepoint_list_set_script (\"%s\") failed\n", script_untranslated);
           /* not reached */
           return NULL;
         }
+
+      g_free (script_untranslated);
+      return list;
     }
   else
     return NULL;
@@ -207,7 +208,7 @@ gucharmap_script_chapters_class_init (GucharmapScriptChaptersClass *clazz)
   chapters_class->get_book_codepoint_list = get_book_codepoint_list;
   chapters_class->go_to_character = go_to_character;
 
-  gucharmap_intl_ensure_initialized ();
+  _gucharmap_intl_ensure_initialized ();
 }
 
 GType 
