@@ -1,4 +1,4 @@
-/* $Id: gucharmap-script-codepoint-list.c,v 1.11 2005/11/22 07:46:06 behdad Exp $ */
+/* $Id: gucharmap-script-codepoint-list.c,v 1.13 2006/07/24 23:06:31 behdad Exp $ */
 /*
  * Copyright (c) 2004 Noah Levitt
  *
@@ -19,6 +19,7 @@
 
 #include "config.h"
 #include <glib.h>
+#include "gucharmap-intl.h"
 #include <string.h>
 #include "gucharmap-script-codepoint-list.h"
 #include "unicode-scripts.h"
@@ -254,6 +255,8 @@ gucharmap_script_codepoint_list_class_init (GucharmapScriptCodepointListClass *c
   codepoint_list_class->get_last_index = get_last_index;
   
   gobject_class->finalize = finalize;
+
+  _gucharmap_intl_ensure_initialized ();
 }
 
 static void 
