@@ -1,4 +1,4 @@
-/* $Id: gucharmap-search-dialog.c,v 1.21 2006/02/12 00:07:14 behdad Exp $ */
+/* $Id: gucharmap-search-dialog.c,v 1.25 2006/07/24 23:06:31 behdad Exp $ */
 /*
  * Copyright (c) 2004 Noah Levitt
  *
@@ -593,15 +593,30 @@ search_completed (GucharmapSearchDialog *search_dialog)
 
   if (found_char == (gunichar)(-1))
     information_dialog (search_dialog, _("Not found."));
-
-  gtk_widget_set_sensitive (priv->prev_button, TRUE);
-  gtk_widget_set_sensitive (priv->next_button, TRUE);
+  else
+    {
+      gtk_widget_set_sensitive (priv->prev_button, TRUE);
+      gtk_widget_set_sensitive (priv->next_button, TRUE);
+    }
 
   gdk_window_set_cursor (GTK_WIDGET (search_dialog)->window, NULL);
 }
 
-void
-gucharmap_search_dialog_start_search (GucharmapSearchDialog *search_dialog,
+static gboolean
+_entry_is_empty (GtkEntry *entry)
+{
+  const gchar *text = gtk_entry_get_text (entry);
+  const gchar *p;	/* points into text */
+
+  for (p = text;
+       p[0] != '\0' && g_unichar_isspace (g_utf8_get_char (p));
+       p = g_utf8_next_char (p))
+    ;
+  return p[0] == '\0';
+}
+
+static void
+_gucharmap_search_dialog_fire_search (GucharmapSearchDialog *search_dialog,
                                       GucharmapDirection     direction)
 {
   GucharmapSearchDialogPrivate *priv = GUCHARMAP_SEARCH_DIALOG_GET_PRIVATE (search_dialog);
@@ -650,6 +665,18 @@ gucharmap_search_dialog_start_search (GucharmapSearchDialog *search_dialog,
   g_signal_emit (search_dialog, gucharmap_search_dialog_signals[SEARCH_START], 0);
 }
 
+void
+gucharmap_search_dialog_start_search (GucharmapSearchDialog *search_dialog,
+                                      GucharmapDirection     direction)
+{
+  GucharmapSearchDialogPrivate *priv = GUCHARMAP_SEARCH_DIALOG_GET_PRIVATE (search_dialog);
+
+  if (priv->search_state != NULL && !_entry_is_empty (GTK_ENTRY (priv->entry)))
+    _gucharmap_search_dialog_fire_search (search_dialog, direction);
+  else
+    gtk_window_present (GTK_WINDOW (search_dialog));
+}
+
 static void
 search_find_response (GtkDialog *dialog,
                       gint       response)
@@ -660,11 +687,11 @@ search_find_response (GtkDialog *dialog,
   switch (response)
     {
       case GUCHARMAP_RESPONSE_PREVIOUS:
-        gucharmap_search_dialog_start_search (search_dialog, GUCHARMAP_DIRECTION_BACKWARD);
+        _gucharmap_search_dialog_fire_search (search_dialog, GUCHARMAP_DIRECTION_BACKWARD);
         break;
 
       case GUCHARMAP_RESPONSE_NEXT:
-        gucharmap_search_dialog_start_search (search_dialog, GUCHARMAP_DIRECTION_FORWARD);
+        _gucharmap_search_dialog_fire_search (search_dialog, GUCHARMAP_DIRECTION_FORWARD);
         break;
 
       default:
@@ -676,18 +703,12 @@ search_find_response (GtkDialog *dialog,
 }
 
 static void
-entry_changed (GtkEntry              *entry,
+entry_changed (GtkObject             *object,
                GucharmapSearchDialog *search_dialog)
 {
   GucharmapSearchDialogPrivate *priv = GUCHARMAP_SEARCH_DIALOG_GET_PRIVATE (search_dialog);
-  const gchar *text = gtk_entry_get_text (entry);
-  const gchar *p;	/* points into text */
 
-  for (p = text;
-       p[0] != '\0' && g_unichar_isspace (g_utf8_get_char (p));
-       p = g_utf8_next_char (p))
-    ;
-  if (p[0] == '\0')
+  if (_entry_is_empty(priv->entry))
     {
       gtk_widget_set_sensitive (priv->prev_button, FALSE);
       gtk_widget_set_sensitive (priv->next_button, FALSE);
@@ -739,7 +760,7 @@ gucharmap_search_dialog_init (GucharmapSearchDialog *search_dialog)
   g_signal_connect (search_dialog, "delete-event", G_CALLBACK (gtk_widget_hide_on_delete), NULL);
 
   /* add buttons */
-  gtk_dialog_add_button (GTK_DIALOG (search_dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
+  gtk_dialog_add_button (GTK_DIALOG (search_dialog), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
 
   priv->prev_button = gtk_button_new ();
   GTK_WIDGET_SET_FLAGS (priv->prev_button, GTK_CAN_DEFAULT);
@@ -773,10 +794,12 @@ gucharmap_search_dialog_init (GucharmapSearchDialog *search_dialog)
   priv->whole_word_option = gtk_check_button_new_with_mnemonic (_("Match _whole word"));
   gtk_widget_show (priv->whole_word_option);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (search_dialog)->vbox), priv->whole_word_option, FALSE, FALSE, 0);
+  g_signal_connect (priv->whole_word_option, "toggled", G_CALLBACK (entry_changed), search_dialog);
 
   priv->annotations_option = gtk_check_button_new_with_mnemonic (_("Search in character _details"));
   gtk_widget_show (priv->annotations_option);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (search_dialog)->vbox), priv->annotations_option, FALSE, FALSE, 0);
+  g_signal_connect (priv->annotations_option, "toggled", G_CALLBACK (entry_changed), search_dialog);
 
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), priv->entry);
 
@@ -813,13 +836,13 @@ gucharmap_search_dialog_class_init (GucharmapSearchDialogClass *clazz)
   gucharmap_search_dialog_signals[SEARCH_START] =
       g_signal_new ("search-start", gucharmap_search_dialog_get_type (), G_SIGNAL_RUN_FIRST, 
                     G_STRUCT_OFFSET (GucharmapSearchDialogClass, search_start), NULL, NULL, 
-                    gucharmap_marshal_VOID__VOID, G_TYPE_NONE, 0);
+                    _gucharmap_marshal_VOID__VOID, G_TYPE_NONE, 0);
   gucharmap_search_dialog_signals[SEARCH_FINISH] =
       g_signal_new ("search-finish", gucharmap_search_dialog_get_type (), G_SIGNAL_RUN_FIRST, 
                     G_STRUCT_OFFSET (GucharmapSearchDialogClass, search_finish), NULL, NULL, 
-                    gucharmap_marshal_VOID__UINT, G_TYPE_NONE, 1, G_TYPE_UINT);
+                    _gucharmap_marshal_VOID__UINT, G_TYPE_NONE, 1, G_TYPE_UINT);
 
-  gucharmap_intl_ensure_initialized ();
+  _gucharmap_intl_ensure_initialized ();
 }
 
 GType
