@@ -1,4 +1,4 @@
-/* $Id: main.c,v 1.71 2006/02/13 21:46:46 behdad Exp $ */
+/* $Id: main.c,v 1.75 2006/07/24 23:06:31 behdad Exp $ */
 /*
  * Copyright (c) 2004 Noah Levitt
  *
@@ -45,22 +45,24 @@ main (gint argc, gchar **argv)
   gint monitor;
   GdkRectangle rect;
 #ifdef HAVE_GNOME
+  GnomeProgram *program;
   GOptionContext *context;
 #else
   GError *error = NULL;
 #endif
 
- gucharmap_intl_ensure_initialized ();
+ _gucharmap_intl_ensure_initialized ();
  textdomain (GETTEXT_PACKAGE);
 
 #ifdef HAVE_GNOME
   context = g_option_context_new ("");
   g_option_context_add_main_entries (context, goptions, GETTEXT_PACKAGE);
 
-  gnome_program_init ("gucharmap", VERSION, LIBGNOMEUI_MODULE, argc, argv,
-		      GNOME_PARAM_APP_DATADIR, DATADIR,
-		      GNOME_PARAM_GOPTION_CONTEXT, context,
-		      NULL);
+  program = gnome_program_init ("gucharmap", VERSION, LIBGNOMEUI_MODULE,
+		 		argc, argv,
+				GNOME_PARAM_APP_DATADIR, DATADIR,
+				GNOME_PARAM_GOPTION_CONTEXT, context,
+				NULL);
 #else
   if (!gtk_init_with_args (&argc, &argv, "", goptions, GETTEXT_PACKAGE, &error))
     {
@@ -71,6 +73,9 @@ main (gint argc, gchar **argv)
     }
 #endif
 
+  g_set_application_name (_("Gucharmap"));
+  gtk_window_set_default_icon_name ("gucharmap");
+
   window = gucharmap_window_new ();
   gucharmap_window_set_text_to_copy_visible (GUCHARMAP_WINDOW (window), TRUE);
   gucharmap_window_set_font_selection_visible (GUCHARMAP_WINDOW (window), TRUE);
@@ -98,6 +103,10 @@ main (gint argc, gchar **argv)
 
   gtk_main ();
 
+#ifdef HAVE_GNOME
+  g_object_unref (program);
+#endif
+
   return 0;
 }
 
